@@ -1,3 +1,5 @@
+import logging
+from logging import Logger
 from time import sleep
 from typing import Final, Type, TypeVar
 
@@ -84,6 +86,10 @@ class CommandMessage:
     def __init__(self, *_):
         self._compute_bcc()
 
+    @classmethod
+    def from_dict(cls, **kwargs: int):
+        return cls(*kwargs.values())
+
     def _compute_bcc(self, *args: int):
         self.BCC = self.EOT
         for data in (self.ID, self.STX, self.CMD, *args, self.ETX):
@@ -132,9 +138,12 @@ class ResponseMessage:
     def is_valid(self):
         return len(self._origin) > 0 and self.BCC == self._origin[-1]
 
+    def as_dict(self):
+        return {'error': self.ERROR - 0x20}
+
     def __repr__(self) -> str:
         return tabulate(
-            ((k, hex(v)) for k, v in self.__dict__.items() if type(v) == int),
+            ((k, v) for k, v in self.as_dict().items()),
             headers=('Name', 'Code'),
             colalign=('left', 'right'),
             tablefmt="pretty"
@@ -204,6 +213,16 @@ class StatusResponse(ResponseMessage):
             self.STAT4, self.TYPE4, self.OPAC4, self.LENG4
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'disp': self.DISP,
+            'stat1': self.STAT1, 'type1': self.TYPE1 - 0x30, 'opac1': self.OPAC1 - 0x20, 'leng1': self.LENG1 - 0x20,
+            'stat2': self.STAT2, 'type2': self.TYPE2 - 0x30, 'opac2': self.OPAC2 - 0x20, 'leng2': self.LENG2 - 0x20,
+            'stat3': self.STAT3, 'type3': self.TYPE3 - 0x30, 'opac3': self.OPAC3 - 0x20, 'leng3': self.LENG3 - 0x20,
+            'stat4': self.STAT4, 'type4': self.TYPE4 - 0x30, 'opac4': self.OPAC4 - 0x20, 'leng4': self.LENG4 - 0x20,
+        }
+
 
 class PurgeCommand(CommandMessage):
     """
@@ -258,6 +277,15 @@ class PurgeResponse(ResponseMessage):
             self.EXIT4, self.REJECT4, self.TYPE4
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'exit1': self.EXIT1 - 0x20, 'reject1': self.REJECT1 - 0x20, 'type1': self.TYPE1 - 0x30,
+            'exit2': self.EXIT2 - 0x20, 'reject2': self.REJECT2 - 0x20, 'type2': self.TYPE2 - 0x30,
+            'exit3': self.EXIT3 - 0x20, 'reject3': self.REJECT3 - 0x20, 'type3': self.TYPE3 - 0x30,
+            'exit4': self.EXIT4 - 0x20, 'reject4': self.REJECT4 - 0x20, 'type4': self.TYPE4 - 0x30,
+        }
+
 
 class DispenseCommand(CommandMessage):
     """
@@ -284,6 +312,13 @@ class DispenseCommand(CommandMessage):
             (args + (self.QTY1, self.QTY2, self.QTY3, self.QTY4, self.TO1, self.TO2)[len(args):])[:6]
         super().__init__(*args)
 
+    @classmethod
+    def from_dict(cls, qty1=0, qty2=0, qty3=0, qty4=0, to=0, **_):
+        return super().from_dict(
+            QTY1=qty1 + 0x20, QTY2=qty2 + 0x20, QTY3=qty3 + 0x20, QTY4=qty4 + 0x20,
+            TO1=0x20 if to == 0 else 0x1C, TO2=0x20 if to == 0 else to + 0x30
+        )
+
     def _compute_bcc(self, *_):
         super()._compute_bcc(self.QTY1, self.QTY2, self.QTY3, self.QTY4, self.TO1, self.TO2, *[self.RSV] * 9)
 
@@ -329,6 +364,15 @@ class DispenseResponse(ResponseMessage):
             *self._origin[-2 - 9:-2]
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'exit1': self.EXIT1 - 0x20, 'reject1': self.REJECT1 - 0x20, 'type1': self.TYPE1 - 0x30,
+            'exit2': self.EXIT2 - 0x20, 'reject2': self.REJECT2 - 0x20, 'type2': self.TYPE2 - 0x30,
+            'exit3': self.EXIT3 - 0x20, 'reject3': self.REJECT3 - 0x20, 'type3': self.TYPE3 - 0x30,
+            'exit4': self.EXIT4 - 0x20, 'reject4': self.REJECT4 - 0x20, 'type4': self.TYPE4 - 0x30,
+        }
+
 
 class TestDispenseCommand(DispenseCommand):
     """
@@ -391,6 +435,15 @@ class LastStatusResponse(ResponseMessage):
             self.EXIT4, self.REJECT4, self.TYPE4,
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'exit1': self.EXIT1 - 0x20, 'reject1': self.REJECT1 - 0x20, 'type1': self.TYPE1 - 0x30,
+            'exit2': self.EXIT2 - 0x20, 'reject2': self.REJECT2 - 0x20, 'type2': self.TYPE2 - 0x30,
+            'exit3': self.EXIT3 - 0x20, 'reject3': self.REJECT3 - 0x20, 'type3': self.TYPE3 - 0x30,
+            'exit4': self.EXIT4 - 0x20, 'reject4': self.REJECT4 - 0x20, 'type4': self.TYPE4 - 0x30,
+        }
+
 
 class SensorDiagnosticsCommand(CommandMessage):
     """
@@ -407,6 +460,10 @@ class SensorDiagnosticsCommand(CommandMessage):
         self.POS = args[0]
         super().__init__(*args)
 
+    @classmethod
+    def from_dict(cls, pos=1, **_):
+        return super().from_dict(POS=pos + 0x30)
+
     def _compute_bcc(self, *_):
         super()._compute_bcc(self.POS)
 
@@ -429,6 +486,13 @@ class SensorDiagnosticsResponse(ResponseMessage):
     def _compute_bcc(self, *_):
         super()._compute_bcc(self.ERROR, self.OPAC, self.LENG, self.DIVERT, self.REJECT)
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'opac': self.OPAC - 0x20, 'leng': self.LENG - 0x20,
+            'divert': self.DIVERT - 0x20, 'reject': self.REJECT - 0x20
+        }
+
 
 class SetBillOpacitiesCommand(CommandMessage):
     """
@@ -459,6 +523,19 @@ class SetBillOpacitiesCommand(CommandMessage):
         ) = args[:8]
         super().__init__(*args)
 
+    @classmethod
+    def from_dict(cls, opac1=0, opac2=0, opac3=0, opac4=0, **_):
+        return super().from_dict(
+            OPAC1_HIGH=(opac1 // 0x10) + 0x30,
+            OPAC1_LOW=(opac1 % 0x10) + 0x30,
+            OPAC2_HIGH=(opac2 // 0x10) + 0x30,
+            OPAC2_LOW=(opac2 % 0x10) + 0x30,
+            OPAC3_HIGH=(opac3 // 0x10) + 0x30,
+            OPAC3_LOW=(opac3 % 0x10) + 0x30,
+            OPAC4_HIGH=(opac4 // 0x10) + 0x30,
+            OPAC4_LOW=(opac4 % 0x10) + 0x30,
+        )
+
     def _compute_bcc(self, *_):
         super()._compute_bcc(
             self.OPAC1_HIGH, self.OPAC1_LOW, self.OPAC2_HIGH, self.OPAC2_LOW,
@@ -517,6 +594,15 @@ class GetBillOpacitiesResponse(ResponseMessage):
             self.OPAC3_HIGH, self.OPAC3_LOW, self.OPAC4_HIGH, self.OPAC4_LOW
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'opac1': ((self.OPAC1_HIGH - 0x30) << 4) + (self.OPAC1_LOW - 0x30),
+            'opac2': ((self.OPAC2_HIGH - 0x30) << 4) + (self.OPAC2_LOW - 0x30),
+            'opac3': ((self.OPAC3_HIGH - 0x30) << 4) + (self.OPAC3_LOW - 0x30),
+            'opac4': ((self.OPAC4_HIGH - 0x30) << 4) + (self.OPAC4_LOW - 0x30),
+        }
+
 
 class SetBillDispenseOrderCommand(CommandMessage):
     """
@@ -542,6 +628,15 @@ class SetBillDispenseOrderCommand(CommandMessage):
         (self.ORDER1, self.ORDER2, self.ORDER3, self.ORDER4) = args[:4]
         super().__init__(*args)
 
+    @classmethod
+    def from_dict(cls, order1=1, order2=2, order3=3, order4=4, **_):
+        return super().from_dict(
+            ORDER1=order1 + 0x30,
+            ORDER2=order2 + 0x30,
+            ORDER3=order3 + 0x30,
+            ORDER4=order4 + 0x30,
+        )
+
     def _compute_bcc(self, *_):
         super()._compute_bcc(self.ORDER1, self.ORDER2, self.ORDER3, self.ORDER4)
 
@@ -582,6 +677,15 @@ class GetBillDispenseOrderResponse(ResponseMessage):
     def _compute_bcc(self, *_):
         super()._compute_bcc(self.ERROR, self.ORDER1, self.ORDER2, self.ORDER3, self.ORDER4)
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'order1': self.ORDER1 - 0x30,
+            'order2': self.ORDER2 - 0x30,
+            'order3': self.ORDER3 - 0x30,
+            'order4': self.ORDER4 - 0x30,
+        }
+
 
 class SetBillLengthsCommand(CommandMessage):
     """
@@ -612,6 +716,19 @@ class SetBillLengthsCommand(CommandMessage):
         ) = args[:8]
         super().__init__(*args)
 
+    @classmethod
+    def from_dict(cls, leng1=0, leng2=0, leng3=0, leng4=0, **_):
+        return super().from_dict(
+            LENG1_HIGH=(leng1 // 0x10) + 0x30,
+            LENG1_LOW=(leng1 % 0x10) + 0x30,
+            LENG2_HIGH=(leng2 // 0x10) + 0x30,
+            LENG2_LOW=(leng2 % 0x10) + 0x30,
+            LENG3_HIGH=(leng3 // 0x10) + 0x30,
+            LENG3_LOW=(leng3 % 0x10) + 0x30,
+            LENG4_HIGH=(leng4 // 0x10) + 0x30,
+            LENG4_LOW=(leng4 % 0x10) + 0x30,
+        )
+
     def _compute_bcc(self, *_):
         super()._compute_bcc(
             self.LENG1_HIGH, self.LENG1_LOW, self.LENG2_HIGH, self.LENG2_LOW,
@@ -659,7 +776,7 @@ class GetBillLengthsResponse(ResponseMessage):
         (
             self.ERROR,
             self.LENG1_HIGH, self.LENG1_LOW, self.LENG2_HIGH, self.LENG2_LOW,
-            self.LENG3_HIGH, self.OPAC3_LOW, self.OPAC4_HIGH, self.OPAC4_LOW
+            self.LENG3_HIGH, self.LENG3_LOW, self.LENG4_HIGH, self.LENG4_LOW
         ) = response[4:-2]
         super().__init__(*response)
 
@@ -667,12 +784,21 @@ class GetBillLengthsResponse(ResponseMessage):
         super()._compute_bcc(
             self.ERROR,
             self.LENG1_HIGH, self.LENG1_LOW, self.LENG2_HIGH, self.LENG2_LOW,
-            self.LENG3_HIGH, self.OPAC3_LOW, self.OPAC4_HIGH, self.OPAC4_LOW
+            self.LENG3_HIGH, self.LENG3_LOW, self.LENG4_HIGH, self.LENG4_LOW
         )
 
+    def as_dict(self):
+        return {
+            **super().as_dict(),
+            'leng1': ((self.LENG1_HIGH - 0x30) << 4) + (self.LENG1_LOW - 0x30),
+            'leng2': ((self.LENG2_HIGH - 0x30) << 4) + (self.LENG2_LOW - 0x30),
+            'leng3': ((self.LENG3_HIGH - 0x30) << 4) + (self.LENG3_LOW - 0x30),
+            'leng4': ((self.LENG4_HIGH - 0x30) << 4) + (self.LENG4_LOW - 0x30),
+        }
+
 
 class PuloonException(Exception):
-    code: int = 0x20
+    code: int = UNKNOWN_ERROR
     message: str = ERROR_CODES[UNKNOWN_ERROR]
     response: ResponseMessage = None
 
@@ -703,22 +829,20 @@ class PuloonLCDM4000:
     response_delay = (0.000, 60.000)
 
     port: Serial
+    logger: Logger
 
-    def __init__(self, port: Serial):
+    def __init__(self, port: Serial, logger: Logger = None):
         self.port = port
+        self.logger = logger or logging.getLogger()
 
-    def _run(self, cmd_class: Type[C], resp_class: Type[R], *args: int) -> R:
-        cmd = cmd_class(*args)
-
+    def _run(self, cmd: CommandMessage, resp_class: Type[R]) -> R:
         for _ in range(3):
-            if __debug__:
-                print('CMD: ' + ' '.join(hex(b) for b in cmd.bytes()))
+            self.logger.debug(f'CMD: {" ".join(hex(b) for b in cmd.bytes())}')
             self.port.write(cmd.bytes())
             self.port.timeout = self.ack_timeout[1]
 
             ack = self.port.read(1)
-            if __debug__:
-                print('ACK: ' + ' '.join(hex(b) for b in ack))
+            self.logger.debug(f'ACK: {" ".join(hex(b) for b in ack)}')
             if len(ack) > 0 and self.ack == ack[0]:
                 break
         else:
@@ -727,20 +851,17 @@ class PuloonLCDM4000:
         for _ in range(3):
             self.port.timeout = self.response_delay[1]
             data = self.port.read(cmd.response_size())
-            if __debug__:
-                print('RSP: ' + ' '.join(hex(b) for b in data))
+            self.logger.debug(f'RSP: {" ".join(hex(b) for b in data)}')
             resp = resp_class(*data)
             if resp.is_valid():
                 self.port.write(chr(self.ack).encode('ascii'))
                 eot = self.port.read(1)
-                if __debug__:
-                    print('EOT: ' + ' '.join(hex(b) for b in eot))
+                self.logger.debug(f'EOT: {" ".join(hex(b) for b in eot)}')
                 if len(eot) > 0 and self.eot == eot[0]:
                     if resp.ERROR != NO_ERROR:
                         raise PuloonException(resp.ERROR - NO_ERROR, response=resp)
                     break
-            if __debug__:
-                print(resp)
+            self.logger.debug(f'\n{repr(resp)}')
             self.port.write(chr(self.nak).encode('ascii'))
         else:
             raise PuloonException(RESPONSE_TIMEOUT)
@@ -759,7 +880,7 @@ class PuloonLCDM4000:
 
     def status(self) -> StatusResponse:
         """This command shows the current sensor status and the configuration of cassette in the top position."""
-        return self._run(StatusCommand, StatusResponse)
+        return self._run(StatusCommand.from_dict(), StatusResponse)
 
     def purge(self) -> PurgeResponse:
         """
@@ -774,10 +895,9 @@ class PuloonLCDM4000:
         It will not recover errors completely by JAM or already terminated DISP (dispense) command.
         Therefore, it is recommended to use carefully.
         """
-        return self._run(PurgeCommand, PurgeResponse)
+        return self._run(PurgeCommand.from_dict(), PurgeResponse)
 
-    def dispense(self, qty1: int = 0, qty2: int = 0, qty3: int = 0, qty4: int = 0,
-                 to1: bool = False, to2: int = 0) -> DispenseResponse:
+    def dispense(self, qty1: int = 0, qty2: int = 0, qty3: int = 0, qty4: int = 0, to: int = 0) -> DispenseResponse:
         """
         The command will cause to dispenser the requested number of notes from the requested cassette.
         It will check thickness and length of notes, which are individually referred to the specified OPACITY and LENGTH,
@@ -787,31 +907,19 @@ class PuloonLCDM4000:
         """
         assert all(0 <= q <= 40 for q in (qty1, qty2, qty3, qty4)), "Quantity should be in range of 0 and 40"
         assert 0 < sum((qty1, qty2, qty3, qty4)) <= 40, "Quantity should be at least 1 and maximum 40 in total"
-        assert 0 <= to2 <= 9, "Timeout should be in range of 0 and 9"
-        return self._run(
-            DispenseCommand,
-            DispenseResponse,
-            *(q + 0x20 for q in (qty1, qty2, qty3, qty4)),
-            0x1C if to1 else 0x20,
-            to2 + 0x30 if to1 else 0x20
-        )
+        assert 0 <= to <= 9, "Timeout should be in range of 0 and 9"
+        return self._run(DispenseCommand.from_dict(qty1, qty2, qty3, qty4, to), DispenseResponse)
 
-    def test_dispense(self, qty1: int = 0, qty2: int = 0, qty3: int = 0, qty4: int = 0,
-                      to1: bool = False, to2: int = 0) -> TestDispenseResponse:
+    def test_dispense(self, qty1: int = 0, qty2: int = 0, qty3: int = 0, qty4: int = 0, to: int = 0) \
+            -> TestDispenseResponse:
         """
         The command will cause to reject the specified number of notes from the cassette to the reject tray.
         All the specified notes will move into the reject tray.
         """
         assert all(0 <= q <= 40 for q in (qty1, qty2, qty3, qty4)), "Quantity should be in range of 0 and 40"
         assert 0 < sum((qty1, qty2, qty3, qty4)) <= 40, "Quantity should be at least 1 and maximum 40 in total"
-        assert 0 <= to2 <= 9, "Timeout should be in range of 0 and 9"
-        return self._run(
-            TestDispenseCommand,
-            TestDispenseResponse,
-            *(q + 0x20 for q in (qty1, qty2, qty3, qty4)),
-            0x1C if to1 else 0x20,
-            to2 + 0x30 if to1 else 0x20
-        )
+        assert 0 <= to <= 9, "Timeout should be in range of 0 and 9"
+        return self._run(TestDispenseCommand.from_dict(qty1, qty2, qty3, qty4, to), TestDispenseResponse)
 
     def last_status(self) -> LastStatusResponse:
         """
@@ -819,7 +927,7 @@ class PuloonLCDM4000:
         such as PURGE, DISPENSE and TEST DISPENSE.
         Therefore, it is effective only when the prior operation was performed.
         """
-        return self._run(LastStatusCommand, LastStatusResponse)
+        return self._run(LastStatusCommand.from_dict(), LastStatusResponse)
 
     def sensor_diagnostics(self, pos: int = 1) -> SensorDiagnosticsResponse:
         """
@@ -827,12 +935,10 @@ class PuloonLCDM4000:
         The notes are moved to reject tray and the measured OPACITY, LENGTH and SOLENOID TIME of the last note is returned.
         """
         assert 1 <= pos <= 4, "Dispenser has only 4 cassette"
-        return self._run(SensorDiagnosticsCommand, SensorDiagnosticsResponse, pos + 0x30)
+        return self._run(SensorDiagnosticsCommand.from_dict(pos), SensorDiagnosticsResponse)
 
-    def set_bill_opacities(self, opac1_high: int = 15, opac1_low: int = 1,
-                           opac2_high: int = 15, opac2_low: int = 1,
-                           opac3_high: int = 15, opac3_low: int = 1,
-                           opac4_high: int = 15, opac4_low: int = 1) -> SetBillOpacitiesResponse:
+    def set_bill_opacities(self, opac1: int = 0, opac2: int = 0, opac3: int = 0, opac4: int = 0) \
+            -> SetBillOpacitiesResponse:
         """
         The command is used to save the reference value in order to detect double notes.
         When the data is changed, it will be saved in the memory of EEPROM and then efficient for the next transaction.
@@ -841,26 +947,12 @@ class PuloonLCDM4000:
         the criterion is set to initial value again.
         Therefore, it is recommended for user to check the value of the saved value of OPACITY when it is turned on.
         """
-        assert all(1 <= v <= 15 for v in (
-            opac1_high, opac1_low, opac2_high, opac2_low,
-            opac3_high, opac3_low, opac4_high, opac4_low
-        )), "Opacity value should be in range of 1 and 15"
-        return self._run(SetBillOpacitiesCommand, SetBillOpacitiesResponse, *(
-            v + 0x30 for v in (opac1_high, opac1_low, opac2_high, opac2_low,
-                               opac3_high, opac3_low, opac4_high, opac4_low)
-        ))
-
-    def reset_bill_opacities(self) -> SetBillOpacitiesResponse:
-        """
-        The command is used to reset the reference value in order to detect double notes.
-        """
-        return self._run(SetBillOpacitiesCommand, SetBillOpacitiesResponse,
-                         0x00, 0x00, 0x00, 0x00,
-                         0x00, 0x00, 0x00, 0x00)
+        assert all(0 <= v <= 255 for v in (opac1, opac2, opac3, opac4)), "Opacity value should be in range of 0 and 255"
+        return self._run(SetBillOpacitiesCommand.from_dict(opac1, opac2, opac3, opac4), SetBillOpacitiesResponse)
 
     def get_bill_opacities(self) -> GetBillOpacitiesResponse:
         """The command will get the OPACITY data from each cassette."""
-        return self._run(GetBillOpacitiesCommand, GetBillOpacitiesResponse)
+        return self._run(GetBillOpacitiesCommand.from_dict(), GetBillOpacitiesResponse)
 
     def set_bill_dispense_order(self, order1: int = 1, order2: int = 2,
                                 order3: int = 3, order4: int = 4) -> SetBillDispenseOrderResponse:
@@ -877,17 +969,17 @@ class PuloonLCDM4000:
         assert all(1 <= v <= 4 for v in (order1, order2, order3, order4)), \
             "Order value should be in range of 1 and 4"
         assert len({order1, order2, order3, order4}) == 4, "Order values should be unique"
-        return self._run(SetBillDispenseOrderCommand, SetBillDispenseOrderResponse,
-                         *(v + 0x30 for v in (order1, order2, order3, order4)))
+        return self._run(
+            SetBillDispenseOrderCommand.from_dict(order1, order2, order3, order4),
+            SetBillDispenseOrderResponse
+        )
 
     def get_bill_dispense_order(self) -> GetBillDispenseOrderResponse:
         """The command will get the bill dispense order data."""
-        return self._run(GetBillDispenseOrderCommand, GetBillDispenseOrderResponse)
+        return self._run(GetBillDispenseOrderCommand.from_dict(), GetBillDispenseOrderResponse)
 
-    def set_bill_lengths(self, leng1_high: int = 15, leng1_low: int = 1,
-                         leng2_high: int = 15, leng2_low: int = 1,
-                         leng3_high: int = 15, leng3_low: int = 1,
-                         leng4_high: int = 15, leng4_low: int = 1) -> SetBillLengthsResponse:
+    def set_bill_lengths(self, leng1: int = 0, leng2: int = 0, leng3: int = 0, leng4: int = 0) \
+            -> SetBillLengthsResponse:
         """
         The command is used to save the reference value in order to detect double notes.
         When the data is changed, it will be saved in the memory of EEPROM and then efficient for the next transaction.
@@ -896,23 +988,9 @@ class PuloonLCDM4000:
         the criterion is set to initial value again.
         Therefore, it is recommended for user to check the value of the saved value of LENGTH when it is turned on.
         """
-        assert all(1 <= v <= 15 for v in (
-            leng1_high, leng1_low, leng2_high, leng2_low,
-            leng3_high, leng3_low, leng4_high, leng4_low
-        )), "Length value should be in range of 1 and 15"
-        return self._run(SetBillLengthsCommand, SetBillLengthsResponse, *(
-            v + 0x30 for v in (leng1_high, leng1_low, leng2_high, leng2_low,
-                               leng3_high, leng3_low, leng4_high, leng4_low)
-        ))
-
-    def reset_bill_lengths(self) -> SetBillLengthsResponse:
-        """
-        The command is used to reset the reference value in order to detect double notes.
-        """
-        return self._run(SetBillLengthsCommand, SetBillLengthsResponse,
-                         0x00, 0x00, 0x00, 0x00,
-                         0x00, 0x00, 0x00, 0x00)
+        assert all(0 <= v <= 255 for v in (leng1, leng2, leng3, leng4)), "Length value should be in range of 1 and 255"
+        return self._run(SetBillLengthsCommand.from_dict(leng1, leng2, leng3, leng4), SetBillLengthsResponse)
 
     def get_bill_lengths(self) -> GetBillLengthsResponse:
         """The command will get to saved length data for each cassette."""
-        return self._run(GetBillLengthsCommand, GetBillLengthsResponse)
+        return self._run(GetBillLengthsCommand.from_dict(), GetBillLengthsResponse)
